@@ -38,8 +38,8 @@ use std::{
     path::Path,
     sync::atomic::{AtomicUsize, Ordering},
 };
-use time::{format_description, Duration, OffsetDateTime, Time, UtcOffset};
 use symlink::{symlink_file, remove_symlink_file};
+use time::{format_description, Duration, OffsetDateTime, Time, UtcOffset};
 
 /// A file appender with the ability to rotate log files at a fixed schedule.
 ///
@@ -107,7 +107,6 @@ struct Inner {
     log_filename_prefix: String,
     rotation: Rotation,
     next_date: AtomicUsize,
-    symlink: bool,
 }
 
 // === impl RollingFileAppender ===
@@ -120,10 +119,6 @@ impl RollingFileAppender {
     /// `file_name_prefix` arguments determine the location and file name's _prefix_
     /// of the log file. `RollingFileAppender` will automatically append the current date
     /// and hour (UTC format) to the file name.
-    /// 
-    /// symlink: Will create a symlink file for current rolling file.
-    /// 
-    /// offset: Use local timezone offset for time in rolling file name, default is UTC time.
     ///
     /// Alternatively, a `RollingFileAppender` can be constructed using one of the following helpers:
     ///
@@ -141,22 +136,16 @@ impl RollingFileAppender {
     /// ```rust
     /// # fn docs() {
     /// use tracing_appender::rolling::{RollingFileAppender, Rotation};
-    /// let file_appender = RollingFileAppender::new(Rotation::HOURLY, "/some/directory", "prefix.log", true, true);
+    /// let file_appender = RollingFileAppender::new(Rotation::HOURLY, "/some/directory", "prefix.log");
     /// # }
     /// ```
     pub fn new(
         rotation: Rotation,
         directory: impl AsRef<Path>,
         file_name_prefix: impl AsRef<Path>,
-        symlink: bool,
-        local_offset: bool,
     ) -> RollingFileAppender {
-        let offset = if local_offset {
-            UtcOffset::current_local_offset().expect("should get local offset!")
-        } else {
-            UtcOffset::UTC
-        };
-        let now = OffsetDateTime::now_utc().to_offset(offset);        
+        let offset = UtcOffset::current_local_offset().expect("should get local offset!");
+        let now = OffsetDateTime::now_utc().to_offset(offset);
         let log_directory = directory.as_ref().to_str().unwrap();
         let log_filename_prefix = file_name_prefix.as_ref().to_str().unwrap();
 
@@ -166,14 +155,12 @@ impl RollingFileAppender {
             create_writer(log_directory, &filename).expect("failed to create appender"),
         );
 
-        if symlink {
-            // Create a symlink to latest log file.
-            let latest_path = Path::new(&filename);
-            let symlink_path = Path::new(&log_directory).join(&log_filename_prefix);
-            let _ = remove_symlink_file(&symlink_path);
-            if let Err(err) = symlink_file(&latest_path, &symlink_path) {
-                eprintln!("Couldn't create symlink: {}", err);
-            }
+        // Create a symlink to latest log file.
+        let latest_path = Path::new(&filename);
+        let symlink_path = Path::new(&log_directory).join(&log_filename_prefix);
+        let _ = remove_symlink_file(&symlink_path);
+        if let Err(err) = symlink_file(&latest_path, &symlink_path) {
+            eprintln!("Couldn't create symlink: {}", err);
         }
 
         Self {
@@ -186,7 +173,6 @@ impl RollingFileAppender {
                         .unwrap_or(0),
                 ),
                 rotation,
-                symlink,
             },
             writer,
             offset,
@@ -259,10 +245,8 @@ impl<'a> tracing_subscriber::fmt::writer::MakeWriter<'a> for RollingFileAppender
 pub fn minutely(
     directory: impl AsRef<Path>,
     file_name_prefix: impl AsRef<Path>,
-    symlink: bool,
-    local_offset: bool,
 ) -> RollingFileAppender {
-    RollingFileAppender::new(Rotation::MINUTELY, directory, file_name_prefix, symlink, local_offset)
+    RollingFileAppender::new(Rotation::MINUTELY, directory, file_name_prefix)
 }
 
 /// Creates an hourly, rolling file appender.
@@ -296,10 +280,8 @@ pub fn minutely(
 pub fn hourly(
     directory: impl AsRef<Path>,
     file_name_prefix: impl AsRef<Path>,
-    symlink: bool,
-    local_offset: bool,
 ) -> RollingFileAppender {
-    RollingFileAppender::new(Rotation::HOURLY, directory, file_name_prefix, symlink, local_offset)
+    RollingFileAppender::new(Rotation::HOURLY, directory, file_name_prefix)
 }
 
 /// Creates a file appender that rotates daily.
@@ -334,10 +316,8 @@ pub fn hourly(
 pub fn daily(
     directory: impl AsRef<Path>,
     file_name_prefix: impl AsRef<Path>,
-    symlink: bool,
-    local_offset: bool,
 ) -> RollingFileAppender {
-    RollingFileAppender::new(Rotation::DAILY, directory, file_name_prefix, symlink, local_offset)
+    RollingFileAppender::new(Rotation::DAILY, directory, file_name_prefix)
 }
 
 /// Creates a non-rolling, file appender
@@ -368,7 +348,7 @@ pub fn daily(
 ///
 /// This will result in a log file located at `/some/path/non-rolling.log`.
 pub fn never(directory: impl AsRef<Path>, file_name: impl AsRef<Path>) -> RollingFileAppender {
-    RollingFileAppender::new(Rotation::NEVER, directory, file_name, false, false)
+    RollingFileAppender::new(Rotation::NEVER, directory, file_name)
 }
 
 /// Defines a fixed period for rolling of a log file.
@@ -521,15 +501,13 @@ impl Inner {
                     eprintln!("Couldn't flush previous writer: {}", err);
                 }
                 *file = new_file;
-
-                if self.symlink {
-                    // Create a symlink to latest log file.
-                    let latest_path = Path::new(&filename);
-                    let symlink_path = Path::new(&self.log_directory).join(&self.log_filename_prefix);
-                    let _ = remove_symlink_file(&symlink_path);
-                    if let Err(err) = symlink_file(&latest_path, &symlink_path) {
-                        eprintln!("Couldn't create symlink: {}", err);
-                    }
+                
+                // Create a symlink to latest log file.
+                let latest_path = Path::new(&filename);
+                let symlink_path = Path::new(&self.log_directory).join(&self.log_filename_prefix);
+                let _ = remove_symlink_file(&symlink_path);
+                if let Err(err) = symlink_file(&latest_path, &symlink_path) {
+                    eprintln!("Couldn't create symlink: {}", err);
                 }
             }
             Err(err) => eprintln!("Couldn't create writer for logs: {}", err),
@@ -608,7 +586,7 @@ mod test {
 
     fn test_appender(rotation: Rotation, file_prefix: &str) {
         let directory = tempfile::tempdir().expect("failed to create tempdir");
-        let mut appender = RollingFileAppender::new(rotation, directory.path(), file_prefix, false, false);
+        let mut appender = RollingFileAppender::new(rotation, directory.path(), file_prefix);
 
         let expected_value = "Hello";
         write_to_log(&mut appender, expected_value);
